from pyrezfix.models import APIResponseBase
from .Page import Page
class Base(APIResponseBase):
    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.page = Page(**kwargs.get("page", None)) or None
